@@ -1,5 +1,5 @@
 package Stepford;
-$Stepford::VERSION = '0.002005';
+$Stepford::VERSION = '0.002006';
 use strict;
 use warnings;
 
@@ -19,7 +19,7 @@ Stepford - A vaguely Rake/Make/Cake-like thing for Perl - create steps and let a
 
 =head1 VERSION
 
-version 0.002005
+version 0.002006
 
 =head1 SYNOPSIS
 
@@ -61,8 +61,8 @@ version 0.002005
 
     my $planner = Stepford::Planner->new(
         step_namespaces => 'My::Step',
-        logger          => $log_dispatch_object,    # optional
-        jobs            => 4,                       # optional
+        logger          => $log_object,    # optional
+        jobs            => 4,              # optional
     );
 
     # Runs all the steps needed to get to the final_steps.
